@@ -10,7 +10,7 @@
 #ifndef _OKULAR_AUDIOPLAYER_H_
 #define _OKULAR_AUDIOPLAYER_H_
 
-#include "okular_export.h"
+#include "okularcore_export.h"
 
 #include <QtCore/QObject>
 
@@ -27,7 +27,7 @@ class SoundAction;
  * Singleton utility class to play sounds in documents using the KDE sound
  * system.
  */
-class OKULAR_EXPORT AudioPlayer : public QObject
+class OKULARCORE_EXPORT AudioPlayer : public QObject
 {
     Q_OBJECT
 
