@@ -12,9 +12,7 @@
 
 #include <QtCore/QObject>
 
-namespace ThreadWeaver {
-    class Job;
-}
+#include <threadweaver/queue.h>
 
 namespace Okular {
 
@@ -33,11 +31,14 @@ class PageController : public QObject
 
         void addRotationJob( RotationJob *job );
 
-    signals:
+    Q_SIGNALS:
         void rotationFinished( int page, Okular::Page *okularPage );
 
-    private slots:
-        void imageRotationDone(ThreadWeaver::Job*);
+    private Q_SLOTS:
+        void imageRotationDone(const ThreadWeaver::JobPointer &job);
+
+    private:
+        ThreadWeaver::Queue m_weaver;
 };
 
 }
