@@ -33,6 +33,7 @@
 #include "core/observer.h"
 #include "core/tile.h"
 #include "settings_core.h"
+#include "ui/debug_ui.h"
 
 Q_GLOBAL_STATIC_WITH_ARGS( QPixmap, busyPixmap, ( KIconLoader::global()->loadIcon(QLatin1String("okular"), KIconLoader::NoGroup, 32, KIconLoader::DefaultState, QStringList(), 0, true) ) )
 
@@ -122,6 +123,7 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
     bool canDrawAnnotations = (flags & Annotations) && !page->m_annotations.isEmpty();
     bool enhanceLinks = (flags & EnhanceLinks) && Okular::Settings::highlightLinks();
     bool enhanceImages = (flags & EnhanceImages) && Okular::Settings::highlightImages();
+
     // vectors containing objects to draw
     // make this a qcolor, rect map, since we don't need
     // to know s_id here! we are only drawing this right?
@@ -189,9 +191,11 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
                 if ( flags & Okular::Annotation::ExternallyDrawn )
                 {
                     // ExternallyDrawn annots are never rendered by PagePainter.
-                    // Just paint the boundingRect if the annot is BeingMoved
-                    if ( flags & Okular::Annotation::BeingMoved )
+                    // Just paint the boundingRect if the annot is moved or resized.
+                    if ( flags & (Okular::Annotation::BeingMoved | Okular::Annotation::BeingResized) )
+                    {
                         boundingRectOnlyAnn = ann;
+                    }
                     continue;
                 }
 
@@ -881,7 +885,7 @@ void PagePainter::cropPixmapOnImage( QImage & dest, const QPixmap * src, const Q
 void PagePainter::recolor(QImage *image, const QColor &foreground, const QColor &background)
 {
     if (image->format() != QImage::Format_ARGB32_Premultiplied) {
-        qWarning() << "Wrong image format! Converting...";
+        qCWarning(OkularUiDebug) << "Wrong image format! Converting...";
         *image = image->convertToFormat(QImage::Format_ARGB32_Premultiplied);
     }
 
